@@ -123,6 +123,7 @@ def up(
             for param, operator, value in settings.MARATHON_CONSTRAINTS
         ]
 
+    # all args must be strings
     args = [
         "python",
         "service.py",
@@ -130,16 +131,16 @@ def up(
         model_config,
         sim_uid,
         sim_ref_datetime,
-        end_time,
-        duration,
+        str(end_time),
+        str(duration),
         start_mode,
-        pause_timeout,
+        str(pause_timeout),
     ]
 
     marathon_app_definition = MarathonApp(
         args=args,
         container=container,
-        mem=f"{session_memory}",
+        mem=session_memory,
         cpus=settings.CONTAINER_CPUS,
         env=envs,
         labels=labels,
